@@ -18,12 +18,7 @@ def run():
         if not k.startswith('__'):
             print "  {0:<20} : {1}".format(k, v)
     
-    dirs = __conf__.ACTION_DIR
-    if isinstance(__conf__.ACTION_DIR, str):dirs = (__conf__.ACTION_DIR,)
-
-    handlers = []
-    for path in dirs:
-        handlers.extend(load_handlers(path))
+    handlers = load_handlers(__conf__.ACTION_DIR)
     
     print 
     print "UrlHandlers:"
